summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/msn/msnsecureloginhandler.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /kopete/protocols/msn/msnsecureloginhandler.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/msn/msnsecureloginhandler.h')
-rw-r--r--kopete/protocols/msn/msnsecureloginhandler.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/protocols/msn/msnsecureloginhandler.h b/kopete/protocols/msn/msnsecureloginhandler.h
index 8e4dc466..8f913fc7 100644
--- a/kopete/protocols/msn/msnsecureloginhandler.h
+++ b/kopete/protocols/msn/msnsecureloginhandler.h
@@ -17,7 +17,7 @@
#ifndef MSNSECURELOGINHANDLER_H
#define MSNSECURELOGINHANDLER_H
-#include <qobject.h>
+#include <tqobject.h>
namespace KIO
{
@@ -35,7 +35,7 @@ class MSNSecureLoginHandler : public QObject
{
Q_OBJECT
public:
- MSNSecureLoginHandler(const QString &accountId, const QString &password, const QString &authParameters);
+ MSNSecureLoginHandler(const TQString &accountId, const TQString &password, const TQString &authParameters);
~MSNSecureLoginHandler();
@@ -43,9 +43,9 @@ public:
signals:
/**
* TODO: return to const QString &
*/
- void loginSuccesful(QString ticket);
+ void loginSuccesful(TQString ticket);
void loginBadPassword();
void loginFailed();
@@ -60,15 +60,15 @@ private:
/**
* Store the password.
*/
- QString m_password;
+ TQString m_password;
/**
* Store the accountId.
*/
- QString m_accountId;
+ TQString m_accountId;
/**
* Store the authentification parameters
*/
- QString m_authentification;
+ TQString m_authentification;
void displayMetaData(KIO::MetaData data);
};
@@ -43,9 +43,9 @@ public:
signals:
/**
- * TODO: return to const QString &
+ * TODO: return to const TQString &
*/